<?php
/**
 * Plugin Name: Delete Venues
 * Plugin URI: https://boltwood.com/blog/the-events-calendar-delete-venues-with-no-events/
 * Description: Delete any The Events Calendar Plugin venues with no events.
 * Version: 1.0.0
 * Author: Tom Boltwood
 * Author URI: https://boltwood.com
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: boltwood
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

function boltwood_tec_check() {

    if( !is_plugin_active( 'the-events-calendar/the-events-calendar.php' ) ) {

        deactivate_plugins( plugin_basename( __FILE__ ) );

        add_action( 'admin_notices', 'boltwood_show_dependency_plugin_not_active_notice' );
    }
}
add_action( 'admin_init', 'boltwood_tec_check' );

function boltwood_show_dependency_plugin_not_active_notice() {
?>
<div class="notice notice-error is-dismissible">
    <p><?php _e( 'Delete Venues requires The Events Calendar Plugin. The plugin has been deactivated.', 'boltwood' ); ?></p>
</div>
<?php
}

function boltwood_delete_venues() {

    $venues = tribe_get_venues();

    foreach( $venues as $venue ) {

        if ( empty( tribe_get_events( array( 'venue' => $venue->ID ) ) ) ) {

            $to_delete[] =  $venue;
        }
    }

    foreach ( $to_delete as $delete ) {

        wp_trash_post( $delete->ID );
    }
}

function boltwood_delete_empty_venues_menu() {
    add_options_page(
        'Delete Empty Venues',
        'Delete Empty Venues',
        'manage_options',
        'delete-empty-venues',
        'boltwood_delete_empty_venues_page'
    );
}
add_action( 'admin_menu', 'boltwood_delete_empty_venues_menu' );

function boltwood_delete_empty_venues_page() {
?>
<div class="wrap">
    <h1>Delete Empty Venues</h1>
    <form method="post">
        <input name="delete_empty_venues_nonce" type="hidden" value="<?php echo wp_create_nonce( 'delete_empty_venues_nonce' ) ?>">
        <p>Click the button to delete all empty venues.</p>
        <p><input type="submit" name="delete_empty_venues" class="button button-primary" value="Delete Empty Venues"></p>
    </form>
</div>
<?php
}

add_action('admin_init', 'boltwood_delete_empty_venues_form_handler');

function boltwood_delete_empty_venues_form_handler() {

    if ( isset( $_POST['delete_empty_venues_nonce'] ) && wp_verify_nonce( $_POST['delete_empty_venues_nonce'], 'delete_empty_venues_nonce' ) && isset( $_POST['delete_empty_venues'] ) ) {
        
        boltwood_delete_venues();
        
        add_action( 'admin_notices', 'boltwood_delete_empty_venues_admin_notice' );
}
}

function boltwood_delete_empty_venues_admin_notice() {
?>
<div class="notice notice-success is-dismissible">
    <p><?php _e( 'Empty venues have been deleted.', 'boltwood' ); ?></p>
</div>
<?php
}